# Generated by Django 4.2.5 on 2023-09-28 15:09

import django.db.models.deletion
import django.db.models.manager
import edc_sites.models
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        ("edc_visit_schedule", "0011_alter_historicalvisitschedule_device_created_and_more"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="subjectschedulehistory",
            managers=[
                ("objects", django.db.models.manager.Manager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
        migrations.AddField(
            model_name="subjectschedulehistory",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
    ]
